@@ -45,8 +45,9 @@ class GreyNoise(object):
     EP_INTERESTING = "interesting/{ip_address}"
     EP_NOISE_MULTI = "noise/multi/quick"
     EP_NOISE_CONTEXT = "noise/context/{ip_address}"
+    EP_COMMUNITY_IP = "v3/community/{ip_address}"
     EP_META_METADATA = "meta/metadata"
-    EP_META_PING = "meta/ping"
+    EP_PING = "ping"
     EP_RIOT = "riot/{ip_address}"
     EP_NOT_IMPLEMENTED = "request/{subcommand}"
     UNKNOWN_CODE_MESSAGE = "Code message unknown: {}"
@@ -93,10 +94,11 @@ class GreyNoise(object):
         integration_name=None,
         cache_max_size=None,
         cache_ttl=None,
+        offering=None,
     ):
         if any(
             configuration_value is None
-            for configuration_value in (api_key, timeout, api_server, proxy)
+            for configuration_value in (api_key, timeout, api_server, proxy, offering)
         ):
             config = load_config()
             if api_key is None:
@@ -107,6 +109,8 @@ class GreyNoise(object):
                 timeout = config["timeout"]
             if proxy is None:
                 proxy = config["proxy"]
+            if offering is None:
+                offering = config["offering"]
         self.api_key = api_key
         self.api_server = api_server
         self.timeout = timeout
@@ -114,6 +118,7 @@ class GreyNoise(object):
         self.use_cache = use_cache
         self.integration_name = integration_name
         self.session = requests.Session()
+        self.offering = offering
 
         if cache_ttl is None or not isinstance(cache_ttl, int):
             cache_ttl = 3600
@@ -153,7 +158,13 @@ class GreyNoise(object):
             "User-Agent": " ".join(user_agent_parts),
             "key": self.api_key,
         }
-        url = "/".join([self.api_server, self.API_VERSION, endpoint])
+        if self.offering.lower() == "community":
+            url = "/".join([self.api_server, endpoint])
+        elif endpoint == self.EP_PING:
+            url = "/".join([self.api_server, endpoint])
+        else:
+            url = "/".join([self.api_server, self.API_VERSION, endpoint])
+
         LOGGER.debug(
             "Sending API request...",
             url=url,
@@ -207,8 +218,14 @@ class GreyNoise(object):
         :rtype: dict
 
         """
-        analyzer = Analyzer(self)
-        return analyzer.analyze(text)
+        if self.offering == "community":
+            response = [
+                {"message": "Quick Lookup not supported with Community offering"}
+            ]
+            return response
+        else:
+            analyzer = Analyzer(self)
+            return analyzer.analyze(text)
 
     def filter(self, text, noise_only=False):
         """Filter lines that contain IP addresses from a given text.
@@ -234,14 +251,20 @@ class GreyNoise(object):
         :type ip_address: str
 
         """
-        LOGGER.debug(
-            "Reporting interesting IP: %s...", ip_address, ip_address=ip_address
-        )
-        validate_ip(ip_address)
+        if self.offering == "community":
+            response = {
+                "message": "Interesting report not supported with Community offering"
+            }
+            return response
+        else:
+            LOGGER.debug(
+                "Reporting interesting IP: %s...", ip_address, ip_address=ip_address
+            )
+            validate_ip(ip_address)
 
-        endpoint = self.EP_INTERESTING.format(ip_address=ip_address)
-        response = self._request(endpoint, method="post")
-        return response
+            endpoint = self.EP_INTERESTING.format(ip_address=ip_address)
+            response = self._request(endpoint, method="post")
+            return response
 
     def ip(self, ip_address):
         """Get context associated with an IP address.
@@ -255,7 +278,10 @@ class GreyNoise(object):
         LOGGER.debug("Getting context for %s...", ip_address, ip_address=ip_address)
         validate_ip(ip_address)
 
-        endpoint = self.EP_NOISE_CONTEXT.format(ip_address=ip_address)
+        if self.offering.lower() == "community":
+            endpoint = self.EP_COMMUNITY_IP.format(ip_address=ip_address)
+        else:
+            endpoint = self.EP_NOISE_CONTEXT.format(ip_address=ip_address)
         if self.use_cache:
             cache = self.ip_context_cache
             response = (
@@ -284,18 +310,26 @@ class GreyNoise(object):
 
     def query(self, query, size=None, scroll=None):
         """Run GNQL query."""
-        LOGGER.debug(
-            "Running GNQL query: %s...", query, query=query, size=size, scroll=scroll
-        )
-        params = {"query": query}
-        if size is not None:
-            params["size"] = size
-        if scroll is not None:
-            params["scroll"] = scroll
-        response = self._request(self.EP_GNQL, params=params)
-        return response
+        if self.offering == "community":
+            response = {"message": "GNQL not supported with Community offering"}
+            return response
+        else:
+            LOGGER.debug(
+                "Running GNQL query: %s...",
+                query,
+                query=query,
+                size=size,
+                scroll=scroll,
+            )
+            params = {"query": query}
+            if size is not None:
+                params["size"] = size
+            if scroll is not None:
+                params["scroll"] = scroll
+            response = self._request(self.EP_GNQL, params=params)
+            return response
 
-    def quick(self, ip_addresses, include_invalid=False):
+    def quick(self, ip_addresses, include_invalid=False):  # noqa: C901
         """Get activity associated with one or more IP addresses.
 
         :param ip_addresses: One or more IP addresses to use in the look-up.
@@ -307,96 +341,111 @@ class GreyNoise(object):
         :type include_invalid: bool
 
         """
-
-        if isinstance(ip_addresses, str):
-            ip_addresses = ip_addresses.split(",")
-
-        LOGGER.debug("Getting noise status...", ip_addresses=ip_addresses)
-
-        valid_ip_addresses = [
-            ip_address
-            for ip_address in ip_addresses
-            if validate_ip(ip_address, strict=False)
-        ]
-
-        if self.use_cache:
-            cache = self.ip_quick_check_cache
-            # Keep the same ordering as in the input
-            ordered_results = OrderedDict(
-                (ip_address, cache.get(ip_address)) for ip_address in valid_ip_addresses
-            )
-            api_ip_addresses = [
-                ip_address
-                for ip_address, result in ordered_results.items()
-                if result is None
+        if self.offering == "community":
+            response = [
+                {"message": "Quick Lookup not supported with Community offering"}
             ]
-            if api_ip_addresses:
-                api_results = []
+            return response
+        else:
+            if isinstance(ip_addresses, str):
+                ip_addresses = ip_addresses.split(",")
+
+            LOGGER.debug("Getting noise status...", ip_addresses=ip_addresses)
+
+            valid_ip_addresses = [
+                ip_address
+                for ip_address in ip_addresses
+                if validate_ip(ip_address, strict=False)
+            ]
+
+            if self.use_cache:
+                cache = self.ip_quick_check_cache
+                # Keep the same ordering as in the input
+                ordered_results = OrderedDict(
+                    (ip_address, cache.get(ip_address))
+                    for ip_address in valid_ip_addresses
+                )
+                api_ip_addresses = [
+                    ip_address
+                    for ip_address, result in ordered_results.items()
+                    if result is None
+                ]
+                if api_ip_addresses:
+                    api_results = []
+                    chunks = more_itertools.chunked(
+                        api_ip_addresses, self.IP_QUICK_CHECK_CHUNK_SIZE
+                    )
+                    for chunk in chunks:
+                        api_result = self._request(
+                            self.EP_NOISE_MULTI, json={"ips": chunk}
+                        )
+                        if isinstance(api_result, list):
+                            api_results.extend(api_result)
+                        else:
+                            api_results.append(api_result)
+
+                    for api_result in api_results:
+                        ip_address = api_result["ip"]
+                        ordered_results[ip_address] = cache.setdefault(
+                            ip_address, api_result
+                        )
+                results = list(ordered_results.values())
+
+            else:
+                results = []
                 chunks = more_itertools.chunked(
-                    api_ip_addresses, self.IP_QUICK_CHECK_CHUNK_SIZE
+                    valid_ip_addresses, self.IP_QUICK_CHECK_CHUNK_SIZE
                 )
                 for chunk in chunks:
-                    api_result = self._request(self.EP_NOISE_MULTI, json={"ips": chunk})
-                    if isinstance(api_result, list):
-                        api_results.extend(api_result)
+                    result = self._request(self.EP_NOISE_MULTI, json={"ips": chunk})
+                    if isinstance(result, list):
+                        results.extend(result)
                     else:
-                        api_results.append(api_result)
+                        results.append(result)
 
-                for api_result in api_results:
-                    ip_address = api_result["ip"]
-                    ordered_results[ip_address] = cache.setdefault(
-                        ip_address, api_result
-                    )
-            results = list(ordered_results.values())
+            [
+                results.append({"ip": ip, "noise": False, "code": "404"})
+                for ip in ip_addresses
+                if ip not in valid_ip_addresses and include_invalid
+            ]
 
-        else:
-            results = []
-            chunks = more_itertools.chunked(
-                valid_ip_addresses, self.IP_QUICK_CHECK_CHUNK_SIZE
-            )
-            for chunk in chunks:
-                result = self._request(self.EP_NOISE_MULTI, json={"ips": chunk})
-                if isinstance(result, list):
-                    results.extend(result)
-                else:
-                    results.append(result)
-
-        [
-            results.append({"ip": ip, "noise": False, "code": "404"})
-            for ip in ip_addresses
-            if ip not in valid_ip_addresses and include_invalid
-        ]
-
-        for result in results:
-            code = result["code"]
-            result["code_message"] = self.CODE_MESSAGES.get(
-                code, self.UNKNOWN_CODE_MESSAGE.format(code)
-            )
-        return results
+            for result in results:
+                code = result["code"]
+                result["code_message"] = self.CODE_MESSAGES.get(
+                    code, self.UNKNOWN_CODE_MESSAGE.format(code)
+                )
+            return results
 
     def stats(self, query, count=None):
         """Run GNQL stats query."""
-        LOGGER.debug("Running GNQL stats query: %s...", query, query=query)
-        params = {"query": query}
-        if count is not None:
-            params["count"] = count
-        response = self._request(self.EP_GNQL_STATS, params=params)
-        return response
+        if self.offering == "community":
+            response = {"message": "Stats Query not supported with Community offering"}
+            return response
+        else:
+            LOGGER.debug("Running GNQL stats query: %s...", query, query=query)
+            params = {"query": query}
+            if count is not None:
+                params["count"] = count
+            response = self._request(self.EP_GNQL_STATS, params=params)
+            return response
 
     def metadata(self):
         """Get metadata."""
-        LOGGER.debug("Getting metadata...")
-        response = self._request(self.EP_META_METADATA)
-        return response
+        if self.offering == "community":
+            response = {
+                "message": "Metadata lookup not supported with Community offering"
+            }
+            return response
+        else:
+            LOGGER.debug("Getting metadata...")
+            response = self._request(self.EP_META_METADATA)
+            return response
 
     def test_connection(self):
         """Test the API connection and API key."""
         LOGGER.debug("Testing access to GreyNoise API and for valid API Key")
-        try:
-            self._request(self.EP_META_PING)
-            return "Success: Access and API Key Valid"
-        except Exception as e:
-            return e
+        response = self._request(self.EP_PING)
+        return response
 
     def riot(self, ip_address):
         """Check if IP is in RIOT data set
@@ -407,13 +456,17 @@ class GreyNoise(object):
         :rtype: dict
 
         """
-        LOGGER.debug("Checking RIOT for %s...", ip_address, ip_address=ip_address)
-        validate_ip(ip_address)
+        if self.offering == "community":
+            response = {"message": "RIOT lookup not supported with Community offering"}
+            return response
+        else:
+            LOGGER.debug("Checking RIOT for %s...", ip_address, ip_address=ip_address)
+            validate_ip(ip_address)
 
-        endpoint = self.EP_RIOT.format(ip_address=ip_address)
-        response = self._request(endpoint)
+            endpoint = self.EP_RIOT.format(ip_address=ip_address)
+            response = self._request(endpoint)
 
-        if "ip" not in response:
-            response["ip"] = ip_address
+            if "ip" not in response:
+                response["ip"] = ip_address
 
-        return response
+            return response
